@@ -460,7 +460,7 @@ void send_result_back(gm_job_t * exec_job);
 char *md5sum(char *text);
 
 /**
- * add_server(
+ * add_server
  *
  * adds parsed server to list
  *
@@ -472,6 +472,44 @@ char *md5sum(char *text);
  */
 void add_server(int * server_num, gm_server_t * server_list[GM_LISTSIZE], char * servername);
 
+/**
+ * starts_with
+ *
+ * returns true if string starts with another string
+ *
+ * @param[in] pre - start string
+ * @param[in] str - string to search in
+ *
+ * @return nothing
+ */
+int starts_with(const char *pre, const char *str);
+
+/**
+ * read_filepointer
+ *
+ * reads filepointer into a malloced char and returns size.
+ * increases size if required.
+ *
+ * @param[in] buffer - buffer to read into
+ * @param[in] fp - filepointer to read from
+ *
+ * @return number of bytes read
+ */
+int read_filepointer(char **, FILE*);
+
+/**
+ * read_pipe
+ *
+ * reads pipe into a malloced char and returns size.
+ * increases size if required.
+ *
+ * @param[in] buffer - buffer to read into
+ * @param[in] pipe - pipe to read from
+ *
+ * @return number of bytes read
+ */
+int read_pipe(char **, int);
+
 /**
  * @}
  */
